==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/ServiceCAHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ServiceCAOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.ServiceCA;
import io.fabric8.openshift.api.model.operator.v1.ServiceCABuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ServiceCAHandler implements ResourceHandler<ServiceCA, ServiceCABuilder> {

  @Override
  public String getKind() {
    return ServiceCA.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public ServiceCA create(OkHttpClient client, Config config, String namespace, ServiceCA item) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ServiceCA replace(OkHttpClient client, Config config, String namespace, ServiceCA item) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ServiceCA reload(OkHttpClient client, Config config, String namespace, ServiceCA item) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ServiceCABuilder edit(ServiceCA item) {
    return new ServiceCABuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, ServiceCA item) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, Watcher<ServiceCA> watcher) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, String resourceVersion, Watcher<ServiceCA> watcher) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, ListOptions options, Watcher<ServiceCA> watcher) {
  return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ServiceCA waitUntilReady(OkHttpClient client, Config config, String namespace, ServiceCA item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ServiceCA waitUntilCondition(OkHttpClient client, Config config, String namespace, ServiceCA item, Predicate<ServiceCA> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.3.2-sources.jar: io/fabric8/openshift/client/handlers/ServiceCAHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ServiceCAOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.ServiceCA;
import io.fabric8.openshift.api.model.operator.v1.ServiceCABuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ServiceCAHandler implements ResourceHandler<ServiceCA, ServiceCABuilder> {

  @Override
  public String getKind() {
    return ServiceCA.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public ServiceCA create(OkHttpClient client, Config config, String namespace, ServiceCA item, boolean dryRun) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public ServiceCA replace(OkHttpClient client, Config config, String namespace, ServiceCA item, boolean dryRun) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public ServiceCA reload(OkHttpClient client, Config config, String namespace, ServiceCA item) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ServiceCABuilder edit(ServiceCA item) {
    return new ServiceCABuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, ServiceCA item, boolean dryRun) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, Watcher<ServiceCA> watcher) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, String resourceVersion, Watcher<ServiceCA> watcher) {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ServiceCA item, ListOptions options, Watcher<ServiceCA> watcher) {
  return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ServiceCA waitUntilReady(OkHttpClient client, Config config, String namespace, ServiceCA item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ServiceCA waitUntilCondition(OkHttpClient client, Config config, String namespace, ServiceCA item, Predicate<ServiceCA> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ServiceCAOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
